@@ -1,17 +1,16 @@
-import * as p from "@bokehjs/core/properties"
-import { div } from "@bokehjs/core/dom"
+import type * as p from "@bokehjs/core/properties"
+import {div} from "@bokehjs/core/dom"
 import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import type {Attrs} from "@bokehjs/core/types"
 
 import {HTMLBox, HTMLBoxView, set_size} from "./layout"
 
-
 export class KeystrokeEvent extends ModelEvent {
   constructor(readonly key: string) {
     super()
   }
 
-  protected get event_values(): Attrs {
+  protected override get event_values(): Attrs {
     return {model: this.origin, key: this.key}
   }
 
@@ -21,19 +20,22 @@ export class KeystrokeEvent extends ModelEvent {
 }
 
 export class TerminalView extends HTMLBoxView {
-  model: Terminal
+  declare model: Terminal
+
   term: any // Element
   webLinksAddon: any
   container: HTMLDivElement
   _rendered: boolean
 
-  connect_signals(): void {
+  override connect_signals(): void {
     super.connect_signals()
-    this.connect(this.model.properties.output.change, this.write)
-    this.connect(this.model.properties._clears.change, this.clear)
+
+    const {output, _clears} = this.model.properties
+    this.on_change(output, this.write)
+    this.on_change(_clears, this.clear)
   }
 
-  render(): void {
+  override render(): void {
     super.render()
     this.container = div({class: "terminal-container"})
     set_size(this.container, this.model)
@@ -41,7 +43,7 @@ export class TerminalView extends HTMLBoxView {
     this.term = this.getNewTerminal()
     this.term.onData((value: any) => {
       this.handleOnData(value)
-    });
+    })
 
     this.webLinksAddon = this.getNewWebLinksAddon()
     this.term.loadAddon(this.webLinksAddon)
@@ -49,8 +51,9 @@ export class TerminalView extends HTMLBoxView {
     this.term.open(this.container)
 
     this.term.onRender(() => {
-      if (!this._rendered)
+      if (!this._rendered) {
         this.fit()
+      }
     })
 
     this.write()
@@ -60,10 +63,11 @@ export class TerminalView extends HTMLBoxView {
 
   getNewTerminal(): any {
     const wn = (window as any)
-    if (wn.Terminal)
+    if (wn.Terminal) {
       return new wn.Terminal(this.model.options)
-    else
+    } else {
       return new wn.xtermjs.Terminal(this.model.options)
+    }
   }
 
   getNewWebLinksAddon(): any {
@@ -77,8 +81,9 @@ export class TerminalView extends HTMLBoxView {
 
   write(): void {
     const text = this.model.output
-    if (text == null || !text.length)
+    if (text == null || !text.length) {
       return
+    }
     // https://stackoverflow.com/questions/65367607/how-to-handle-new-line-in-xterm-js-while-writing-data-into-the-terminal
     const cleaned = text.replace(/\r?\n/g, "\r\n")
     // var text = Array.from(cleaned, (x) => x.charCodeAt(0))
@@ -90,25 +95,29 @@ export class TerminalView extends HTMLBoxView {
   }
 
   fit(): void {
-    const width = this.container.offsetWidth;
-    const height = this.container.offsetHeight;
+    const width = this.container.offsetWidth
+    const height = this.container.offsetHeight
     const renderer = this.term._core._renderService
     const cell_width = renderer.dimensions.actualCellWidth || 9
     const cell_height = renderer.dimensions.actualCellHeight || 18
-    if (width == null || height == null || width <= 0 || height <= 0)
+    if (width == null || height == null || width <= 0 || height <= 0) {
       return
+    }
     const cols = Math.max(2, Math.floor(width / cell_width))
     const rows = Math.max(1, Math.floor(height / cell_height))
-    if (this.term.rows !== rows || this.term.cols !== cols)
+    if (this.term.rows !== rows || this.term.cols !== cols) {
       this.term.resize(cols, rows)
+    }
     this.model.ncols = cols
     this.model.nrows = rows
     this._rendered = true
   }
 
-  after_layout(): void {
+  override after_layout(): void {
     super.after_layout()
-    this.fit()
+    if (this.container != null) {
+      this.fit()
+    }
   }
 }
 
@@ -127,21 +136,21 @@ export interface Terminal extends Terminal.Attrs { }
 
 // The Bokeh .ts model corresponding to the Bokeh .py model
 export class Terminal extends HTMLBox {
-  properties: Terminal.Props
+  declare properties: Terminal.Props
 
   constructor(attrs?: Partial<Terminal.Attrs>) {
     super(attrs)
   }
 
-  static __module__ = "panel.models.terminal"
+  static override __module__ = "panel.models.terminal"
 
   static {
-    this.prototype.default_view = TerminalView;
+    this.prototype.default_view = TerminalView
 
-    this.define<Terminal.Props>(({Any, Int, String}) => ({
+    this.define<Terminal.Props>(({Any, Int, Str}) => ({
       _clears:        [ Int,     0 ],
       options:        [ Any,    {} ],
-      output:         [ String, '' ],
+      output:         [ Str, "" ],
       ncols:          [ Int,     0 ],
       nrows:          [ Int,     0 ],
     }))
